@@ -11,6 +11,7 @@ use Template;
 use Log::Log4perl qw(:easy);
 use DateTime;
 use Data::Dumper;
+use List::Util qw/shuffle/;
 #use IPC::Cmd qw/can_run/;
 
 use Moose;
@@ -27,7 +28,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.28';
+our $VERSION = '2.29';
 
 =head1 SYNOPSIS
 
@@ -645,13 +646,26 @@ sub get_nodes{
         }
     }
 
-    if($self->partition){
-        $self->nodelist($href->{$self->partition});
+    #Allow for user defined partition and/or partition/nodelist
+    #Also randomize nodelist so we quit hammering the first node
+    $DB::single=2;
+
+    if($self->partition && $self->nodelist){
+        $DB::single=2;
+        return;
+    }
+    elsif($self->partition){
+        $DB::single=2;
+        my @shuffle = shuffle @{$href->{$self->partition}};
+#        $self->nodelist($href->{$self->partition});
+        $self->nodelist(\@shuffle);
         return;
     }
 
     $self->partition($bpart);
-    $self->nodelist($href->{$bpart});
+#    $self->nodelist($href->{$bpart});
+    my @shuffle = shuffle @{$href->{$bpart}};
+    $self->nodelist(\@shuffle);
 }
 
 =head2 parse_file_slurm
